@@ -2,4 +2,4 @@ from . import prompt, evaluator
 from .data import get_training_data
 from .lm import Dataset, EncodePlus, RelBERT
 from .trainer import Trainer
-from .util import cosine_similarity
+from .util import cosine_similarity, euclidean_distance
